summaryrefslogtreecommitdiffstats
path: root/libnetdata/onewayalloc/onewayalloc.c
diff options
context:
space:
mode:
Diffstat (limited to 'libnetdata/onewayalloc/onewayalloc.c')
-rw-r--r--libnetdata/onewayalloc/onewayalloc.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/libnetdata/onewayalloc/onewayalloc.c b/libnetdata/onewayalloc/onewayalloc.c
index 489ce73d7..05c9f2a9d 100644
--- a/libnetdata/onewayalloc/onewayalloc.c
+++ b/libnetdata/onewayalloc/onewayalloc.c
@@ -176,7 +176,7 @@ void onewayalloc_freez(ONEWAYALLOC *owa __maybe_unused, const void *ptr __maybe_
// not found - it is not ours
// let's free it with the system allocator
- error("ONEWAYALLOC: request to free address 0x%p that is not allocated by this OWA", ptr);
+ netdata_log_error("ONEWAYALLOC: request to free address 0x%p that is not allocated by this OWA", ptr);
#endif
return;
@@ -195,7 +195,7 @@ void onewayalloc_destroy(ONEWAYALLOC *owa) {
OWA_PAGE *head = (OWA_PAGE *)owa;
//info("OWA: %zu allocations of %zu total bytes, in %zu pages of %zu total bytes",
// head->stats_mallocs_made, head->stats_mallocs_size,
// head->stats_pages, head->stats_pages_size);
@@ -195,7 +195,7 @@ void onewayalloc_destroy(ONEWAYALLOC *owa) {
OWA_PAGE *head = (OWA_PAGE *)owa;
- //info("OWA: %zu allocations of %zu total bytes, in %zu pages of %zu total bytes",
+ //netdata_log_info("OWA: %zu allocations of %zu total bytes, in %zu pages of %zu total bytes",
// head->stats_mallocs_made, head->stats_mallocs_size,
// head->stats_pages, head->stats_pages_size);